@@ -23,10 +23,11 @@ class ValidationResult(object):
 
     """
 
-    def __init__(self, is_valid: bool, messages: List[str] = None, errors: List[str] = None, warnings: List[str] = None):
+    def __init__(self, is_valid: bool, messages: List[str] = None, errors: List[str] = None, warnings: List[str] = None, summaries: List[str] = None):
         self._is_valid = is_valid
         self._errors = errors or []
         self._warnings = warnings or []
+        self._summaries = summaries or []
         # For simple messages, classify them as errors or warnings based on the validity of the result
         if messages:
             if is_valid:
@@ -46,6 +47,8 @@ class ValidationResult(object):
             res += '\nERRORS:\n' + '\n'.join(self._errors)
         if self._warnings:
             res += '\nWARNINGS:\n' + '\n'.join(self._warnings)
+        if self._summaries:
+            res += '\nSUMMARIES:\n' + '\n'.join(self._summaries)
         return res
 
     def __repr__(self) -> str:
@@ -55,16 +58,20 @@ class ValidationResult(object):
         is_valid = self._is_valid and other._is_valid
         errors = self._errors + other._errors
         warnings = self._warnings + other._warnings
-        return ValidationResult(is_valid=is_valid, errors=errors, warnings=warnings)
+        summaries = self._summaries + other._summaries
+        return ValidationResult(is_valid=is_valid, errors=errors, warnings=warnings, summaries=summaries)
 
     def get_messages(self) -> List[str]:
-        return self._errors + self._warnings
+        return self._errors + self._warnings + self._summaries
     
     def get_errors(self) -> List[str]:
         return self._errors
     
     def get_warnings(self) -> List[str]:
         return self._warnings
+    
+    def get_summaries(self) -> List[str]:
+        return self._summaries
 
 
 @decorator.decorator
@@ -125,7 +132,7 @@ def _dedupe_messages(messages: List[str]) -> List[str]:
             deduped_messages.append(msg)
     return deduped_messages
 
-def get_validation_response(validation_result, ls_thing=None, commit=False, transaction_id=-1):
+def get_validation_response(validation_result, ls_thing=None, commit=False, transaction_id=-1) -> dict:
     """
     :param validation_result: validation result object
     :type validation_result: validations.ValidationResult
@@ -142,12 +149,16 @@ def get_validation_response(validation_result, ls_thing=None, commit=False, tran
     :return: validation response for the given result
     :rtype: dict
     """
-    has_errors = len(validation_result.get_errors()) > 0
-    has_warnings = len(validation_result.get_warnings()) > 0
+    errors = validation_result.get_errors()
+    warnings = validation_result.get_warnings()
+    summaries = validation_result.get_summaries()
+    
+    has_errors = len(errors) > 0
+    has_warnings = len(warnings) > 0
     
     # Deduplicate error and warning messages
-    errors = _dedupe_messages(validation_result.get_errors())
-    warnings = _dedupe_messages(validation_result.get_warnings())
+    errors = _dedupe_messages(errors)
+    warnings = _dedupe_messages(warnings)
 
     # Build error_messages list of dicts
     error_messages = []
@@ -156,11 +167,7 @@ def get_validation_response(validation_result, ls_thing=None, commit=False, tran
     for msg in warnings:
         error_messages.append({'message': msg, 'errorLevel': 'warning'})
     # Format HTML
-    response_html_header = 'Validation ' + (
-        'Successful' if bool(validation_result) else 'Unsuccessful')
-    html_summary = f'<h3>{response_html_header}</h3>'
-    for err_msg in error_messages:
-        html_summary += f'<p>{err_msg["message"]}</p>'
+    html_summary = _get_html_summary(errors, warnings, summaries)
     resp_dict = {
         'commit': commit,
         'transaction_id': transaction_id,
@@ -173,4 +180,64 @@ def get_validation_response(validation_result, ls_thing=None, commit=False, tran
     }
     if ls_thing:
         resp_dict['results']['thing'] = ls_thing
-    return resp_dict
\ No newline at end of file
+    return resp_dict
+
+
+def _get_html_summary(errors, warnings, summaries, commit=False) -> str:
+    """
+    Format HTML summary for the validation result.
+    """
+    # Lay out HTML template structure
+    HTML_SUMMARY_TEMPLATE = """<p>{instructions}</p>
+    {errors_block}
+    {warnings_block}
+    {summary_block}
+    """
+    ERRORS_TEMPLATE = """<h4 style=\"color:red\">Errors: {count} </h4>
+    <ul>{message_list}</ul>
+    """
+    WARNINGS_TEMPLATE = """<h4>Warnings: {count} </h4>
+    <p>Warnings provide information on issues found in the uploaded data. You can proceed with warnings; however, it is recommended that, if possible, you make the changes suggested by the warnings and upload a new version of the data by using the 'Back' button at the bottom of this screen.<p>
+    <ul>{message_list}</ul>"""
+    SUMMARY_TEMPLATE = """<h4>Summary</h4>
+    <p>Information:</p>
+    <ul>{message_list}</ul>"""
+    MESSAGE_TEMPLATE = """<li>{message}</li>"""
+
+    # Set up variables
+    instructions = ''
+    errors_block = ''
+    warnings_block = ''
+    summary_block = ''
+    if errors:
+        error_messages = '\n'.join(
+            [MESSAGE_TEMPLATE.format(message=error) for error in errors])
+        errors_block = ERRORS_TEMPLATE.format(
+            count=len(errors), message_list=error_messages)
+    if warnings:
+        warnings_messages = '\n'.join(
+            [MESSAGE_TEMPLATE.format(message=warning) for warning in warnings])
+        warnings_block = WARNINGS_TEMPLATE.format(
+            count=len(warnings), message_list=warnings_messages)
+    if summaries:
+        summary_messages = '\n'.join(
+            [MESSAGE_TEMPLATE.format(message=summary) for summary in summaries])
+        summary_block = SUMMARY_TEMPLATE.format(message_list=summary_messages)
+    if commit:
+        instructions = 'Upload completed.'
+        # hide warnings and errors if we've already committed
+        errors_block = ''
+        warnings_block = ''
+    elif errors:
+        instructions = "Please fix the following errors and use the 'Back' button at the bottom of this screen to upload a new version of the data."
+    elif warnings:
+        instructions = "Please review the warnings and summary before uploading."
+    else:
+        instructions = "Please review the summary before uploading."
+    # Format HTML
+    html_summary = HTML_SUMMARY_TEMPLATE.format(
+        instructions=instructions,
+        errors_block=errors_block,
+        warnings_block=warnings_block,
+        summary_block=summary_block)
+    return html_summary
\ No newline at end of file
