@@ -876,6 +876,7 @@ class TestValidationResponse(unittest.TestCase):
         """
         ERR_MSG = 'error 1'
         WARN_MSG = 'warning 1'
+        SUMM_MSG = 'summary 1'
         # Create a warning
         warn = ValidationResult(True, [WARN_MSG])
         assert warn
@@ -892,6 +893,9 @@ class TestValidationResponse(unittest.TestCase):
         assert len(err.get_errors()) == 1
         assert err.get_errors()[0] == ERR_MSG
 
+        # Create a summary
+        summary = ValidationResult(True, summaries=[SUMM_MSG])
+
         # Add them
         valid = warn + err
         assert not valid
@@ -903,6 +907,14 @@ class TestValidationResponse(unittest.TestCase):
         assert len(valid.get_warnings()) == 1
         assert valid.get_warnings()[0] == WARN_MSG
 
+        # Add in the summary
+        valid = valid + summary
+        assert not valid
+        assert len(valid.get_messages()) == 3
+        assert valid.get_messages()[2] == SUMM_MSG
+        assert len(valid.get_summaries()) == 1
+        assert valid.get_summaries()[0] == SUMM_MSG
+
         # Generate and check a response
         response = get_validation_response(valid)
         # Confirm the structure of the response body
@@ -929,3 +941,60 @@ class TestValidationResponse(unittest.TestCase):
             assert False
         except ValueError as e:
             assert str(e) == "ValidationResult cannot be valid and contain error messages"
+    
+    def test_002_html_summary(self):
+        """
+        Test the HTML Summary generated by ValidationResult
+        """
+        ERR_INSTRUCT = "<p>Please fix the following errors and use the 'Back' button at the bottom of this screen to upload a new version of the data.</p>"
+        WARN_INSTRUCT = "<p>Please review the warnings and summary before uploading.</p>"
+        SUCCESS_INSTRUCT = "<p>Please review the summary before uploading.</p>"
+        ERR_1 = 'error 1'
+        ERR_2 = 'error 2'
+        WARN_1 = 'warning 1'
+        WARN_2 = 'warning 2'
+        SUMM_1 = 'summary 1'
+        SUMM_2 = 'summary 2'
+        # No errors or warnings
+        res = ValidationResult(True)
+        html = get_validation_response(res).get('results').get('htmlSummary')
+        self.assertEqual(html.strip(), SUCCESS_INSTRUCT)
+        # 1 errors 1 warning
+        res = ValidationResult(False, errors=[ERR_1], warnings=[WARN_1])
+        html = get_validation_response(res).get('results').get('htmlSummary')
+        self.assertIn(ERR_INSTRUCT, html)
+        self.assertIn('<h4 style="color:red">Errors: 1 </h4>', html)
+        self.assertIn('<h4>Warnings: 1 </h4>', html)
+        self.assertIn(f"<li>{ERR_1}</li>", html)
+        self.assertIn(f"<li>{WARN_1}</li>", html)
+        # Multiple errors & warnings, including dupes
+        res = ValidationResult(False, errors=[ERR_1, ERR_2, ERR_1], warnings=[WARN_1, WARN_1, WARN_2])
+        html = get_validation_response(res).get('results').get('htmlSummary')
+        self.assertIn('<h4 style="color:red">Errors: 2 </h4>', html)
+        self.assertIn('<h4>Warnings: 2 </h4>', html)
+        self.assertIn(f'<li>2 occurrences of: {ERR_1}</li>', html)
+        self.assertNotIn(f"<li>{ERR_1}</li>", html)
+        self.assertIn(f"<li>{ERR_2}</li>", html)
+        self.assertIn(f'<li>2 occurrences of: {WARN_1}</li>', html)
+        self.assertIn(f"<li>{WARN_2}</li>", html)
+        # Warnings, no errors
+        res = ValidationResult(True, warnings=[WARN_1, WARN_2])
+        html = get_validation_response(res).get('results').get('htmlSummary')
+        self.assertIn(WARN_INSTRUCT, html)
+        self.assertIn('<h4>Warnings: 2 </h4>', html)
+        self.assertNotIn('<h4 style="color:red">Errors:', html)
+        # Errors, no warnings
+        res = ValidationResult(False, errors=[ERR_1, ERR_2])
+        html = get_validation_response(res).get('results').get('htmlSummary')
+        self.assertIn(ERR_INSTRUCT, html)
+        self.assertIn('<h4 style="color:red">Errors: 2 </h4>', html)
+        self.assertNotIn('<h4>Warnings:', html)
+        # Errors, warnings, and summaries
+        res = ValidationResult(False, errors=[ERR_1, ERR_2], warnings=[WARN_1, WARN_2], summaries=[SUMM_1, SUMM_2])
+        html = get_validation_response(res).get('results').get('htmlSummary')
+        self.assertIn(ERR_INSTRUCT, html)
+        self.assertIn('<h4 style="color:red">Errors: 2 </h4>', html)
+        self.assertIn('<h4>Warnings: 2 </h4>', html)
+        self.assertIn('<h4>Summary</h4>', html)
+        self.assertIn(f"<li>{SUMM_1}</li>", html)
+        self.assertIn(f"<li>{SUMM_2}</li>", html)
